pub struct StackedPcsDataGpu<F, Digest> { /* private fields */ }Implementations
Sourceimpl<F, Digest> StackedPcsDataGpu<F, Digest>
impl<F, Digest> StackedPcsDataGpu<F, Digest>
Sourcepub fn layout(&self) -> &StackedLayout
pub fn layout(&self) -> &StackedLayout
Layout of the unstacked collection of matrices within the stacked matrix.
Sourcepub fn matrix(&self) -> &Option<PleMatrix<F>>
pub fn matrix(&self) -> &Option<PleMatrix<F>>
The stacked matrix with height 2^{l_skip + n_stack}.
This is optionally cached depending on the prover configuration:
- Caching increases the peak GPU memory but avoids a recomputation during stacked reduction.
- Not caching means the stacked matrix computation is recomputed during stacked reduction, but lowers the peak GPU memory.
Sourcepub fn tree(&self) -> &MerkleTreeGpu<F, Digest>
pub fn tree(&self) -> &MerkleTreeGpu<F, Digest>
Merkle tree of the Reed-Solomon codewords of the stacked matrix.
Depends on k_whir parameter.
Sourceimpl<F, Digest> StackedPcsDataGpu<F, Digest>
impl<F, Digest> StackedPcsDataGpu<F, Digest>
Sourcepub fn mixed_view<'a>(
&'a self,
mat_idx: usize,
width: usize,
) -> Option<DeviceMatrixView<'a, F>>
pub fn mixed_view<'a>( &'a self, mat_idx: usize, width: usize, ) -> Option<DeviceMatrixView<'a, F>>
Returns a view of the specified unstacked matrix in mixed form.
Notes
widthmust be the width of the unstacked matrix.- The unstacked matrix may be strided - this must be handled by the caller.