pub fn rs_code_matrix(
log_blowup: usize,
layout: &StackedLayout,
traces: &[&DeviceMatrix<F>],
stacked_matrix: &Option<PleMatrix<F>>,
device_ctx: &GpuDeviceCtx,
) -> Result<DeviceMatrix<F>, RsCodeMatrixError>Expand description
Computes the Reed-Solomon codeword of each column vector of eval_matrix where the rate is
2^{-log_blowup}. The column vectors are treated as evaluations of a prismalinear extension on
a hyperprism.
Uses stacked_matrix if available, or else stacks traces directly into final codeword matrix
buffer.